==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebPivotDateDimensionOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDateDimensionOptionsDescription } from "./WebPivotDateDimensionOptionsDescription";
/**
 * @hidden
 */
export let WebPivotDateDimensionOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDateDimensionOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDateDimensionOptionsDescriptionMetadata.a == null) {
                WebPivotDateDimensionOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDateDimensionOptionsDescriptionMetadata.c(WebPivotDateDimensionOptionsDescriptionMetadata.a);
            }
            if (a.k(WebPivotDateDimensionOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebPivotDateDimensionOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDateDimensionOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Total", "Boolean");
            a.item("Years", "Boolean");
            a.item("Quarters", "Boolean");
            a.item("Months", "Boolean");
            a.item("FullDate", "Boolean");
        }
        static d(a) {
            WebPivotDateDimensionOptionsDescriptionMetadata.b(a);
            a.ad("WebPivotDateDimensionOptions", () => new WebPivotDateDimensionOptionsDescription());
            a.ac("WebPivotDateDimensionOptions", WebPivotDateDimensionOptionsDescriptionMetadata.a);
        }
    }
    WebPivotDateDimensionOptionsDescriptionMetadata.$t = markType(WebPivotDateDimensionOptionsDescriptionMetadata, 'WebPivotDateDimensionOptionsDescriptionMetadata');
    WebPivotDateDimensionOptionsDescriptionMetadata.a = null;
    return WebPivotDateDimensionOptionsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebPivotDateDimensionOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDateDimensionOptionsDescription } from "./WebPivotDateDimensionOptionsDescription";
/**
 * @hidden
 */
export let WebPivotDateDimensionOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPivotDateDimensionOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPivotDateDimensionOptionsDescriptionMetadata.a == null) {
                WebPivotDateDimensionOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPivotDateDimensionOptionsDescriptionMetadata.c(WebPivotDateDimensionOptionsDescriptionMetadata.a);
            }
            if (a.k(WebPivotDateDimensionOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebPivotDateDimensionOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PivotDateDimensionOptions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Total", "Boolean");
            a.item("Years", "Boolean");
            a.item("Quarters", "Boolean");
            a.item("Months", "Boolean");
            a.item("FullDate", "Boolean");
        }
        static d(a) {
            WebPivotDateDimensionOptionsDescriptionMetadata.b(a);
            a.ae("WebPivotDateDimensionOptions", () => new WebPivotDateDimensionOptionsDescription());
            a.ad("WebPivotDateDimensionOptions", WebPivotDateDimensionOptionsDescriptionMetadata.a);
        }
    }
    WebPivotDateDimensionOptionsDescriptionMetadata.$t = markType(WebPivotDateDimensionOptionsDescriptionMetadata, 'WebPivotDateDimensionOptionsDescriptionMetadata');
    WebPivotDateDimensionOptionsDescriptionMetadata.a = null;
    return WebPivotDateDimensionOptionsDescriptionMetadata;
})();
